@@ -66,6 +66,11 @@ OUTBOX = "outbox"
 # volumes.
 XLEASES = "xleases"
 
+# The size of these volumes is calculated dynamically based on the
+# domain block size and alignment.
+LEASES_SLOTS = 2048
+XLEASES_SLOTS = 1024
+
 # Special volumes available since storage domain version 0
 SPECIAL_VOLUMES_V0 = (METADATA, LEASES, IDS, INBOX, OUTBOX)
 
@@ -73,11 +78,9 @@ SPECIAL_VOLUMES_V0 = (METADATA, LEASES, IDS, INBOX, OUTBOX)
 SPECIAL_VOLUMES_V4 = SPECIAL_VOLUMES_V0 + (XLEASES,)
 
 SPECIAL_VOLUME_SIZES_MIB = {
-    LEASES: 2048,
     IDS: 8,
     INBOX: 16,
     OUTBOX: 16,
-    XLEASES: 1024,
 }
 
 # Storage Domain Types
@@ -161,16 +164,13 @@ ImgsPar = namedtuple("ImgsPar", "imgs,parent")
 ISO_IMAGE_UUID = '11111111-1111-1111-1111-111111111111'
 BLANK_UUID = '00000000-0000-0000-0000-000000000000'
 
-# Blocks used for each lease (valid on all domain types)
-LEASE_BLOCKS = 2048
-
 UNICODE_MINIMAL_VERSION = 3
 
-# The LEASE_OFFSET is used by SANLock to not overlap with safelease in
-# orfer to preserve the ability to acquire both locks (e.g.: during the
-# domain upgrade)
+# The LEASE_SLOT is used by Sanlock to not overlap with safelease in
+# order to preserve the ability to acquire both locks during the domain
+# upgrade from V1 to V3.
 SDM_LEASE_NAME = 'SDM'
-SDM_LEASE_OFFSET = 512 * 2048
+SDM_LEASE_SLOT = 1
 
 
 def getVolsOfImage(allVols, imgUUID):
@@ -539,7 +539,7 @@ class StorageDomainManifest(object):
         """
         return clusterlock.Lease(SDM_LEASE_NAME,
                                  self.getLeasesFilePath(),
-                                 SDM_LEASE_OFFSET)
+                                 SDM_LEASE_SLOT * self.alignment)
 
     def acquireDomainLock(self, hostID):
         self.refresh()
@@ -1285,7 +1285,9 @@ class StorageDomain(object):
         return cls.manifestClass.supports_external_leases(version)
 
     @classmethod
-    def format_external_leases(cls, lockspace, path):
+    def format_external_leases(
+            cls, lockspace, path, alignment=sc.ALIGNMENT_1M,
+            block_size=sc.BLOCK_SIZE_512):
         """
         Format the special xleases volume.
 
@@ -1302,7 +1304,11 @@ class StorageDomain(object):
         """
         with cls.manifestClass.external_leases_backend(
                 lockspace, path) as backend:
-            xlease.format_index(lockspace, backend)
+            xlease.format_index(
+                lockspace,
+                backend,
+                alignment=alignment,
+                block_size=block_size)
 
     def external_leases_path(self):
         return self._manifest.external_leases_path()
