@@ -18,6 +18,9 @@
 # Refer to the README and COPYING files for full details of the license
 #
 
+from __future__ import absolute_import
+from __future__ import division
+
 from contextlib import contextmanager
 
 from monkeypatch import MonkeyPatchScope
