@@ -33,6 +33,7 @@ import pytest
 
 from vdsm import constants
 from vdsm import utils
+from vdsm.storage import constants as sc
 from vdsm.storage import exception as se
 from vdsm.storage import outOfProcess as oop
 from vdsm.storage import xlease
@@ -40,6 +41,7 @@ from vdsm.storage import xlease
 from testlib import make_uuid
 
 from . fakesanlock import FakeSanlock
+from . import userstorage
 
 
 class ReadError(Exception):
@@ -60,14 +62,19 @@ class FailingWriter(xlease.DirectFile):
         raise WriteError
 
 
-# TODO:
-# - Support storage with 512/4k block size.
-# - Support multiple alignments.
-@pytest.fixture(scope="session")
-def tmp_storage(tmpdir_factory):
-    path = tmpdir_factory.mktemp("xlease").join("volume")
-    path.write("")
-    return str(path)
+@pytest.fixture(
+    scope="module",
+    params=[
+        userstorage.PATHS["file-512"],
+        userstorage.PATHS["file-4k"],
+    ],
+    ids=str,
+)
+def user_storage(request):
+    storage = request.param
+    if not os.path.exists(storage.path):
+        pytest.xfail("{} storage not available".format(storage.name))
+    return storage
 
 
 class TemporaryVolume(object):
@@ -75,11 +82,15 @@ class TemporaryVolume(object):
     Temporary xleases volume.
     """
 
-    def __init__(self, path):
+    def __init__(self, storage, alignment):
         """
         Zero storage and format index area.
         """
-        self.backend = xlease.DirectFile(path)
+        self.path = storage.path
+        self.lockspace = make_uuid()
+        self.alignment = alignment
+        self.block_size = storage.sector_size
+        self.backend = xlease.DirectFile(storage.path)
         self.zero_storage()
         self.format_index()
 
@@ -87,7 +98,7 @@ class TemporaryVolume(object):
         """
         Write records to volume index area.
         """
-        index = xlease.VolumeIndex()
+        index = xlease.VolumeIndex(self.alignment, self.block_size)
         with utils.closing(index):
             index.load(self.backend)
             for recnum, record in records:
@@ -98,27 +109,50 @@ class TemporaryVolume(object):
 
     def zero_storage(self):
         # TODO: suport block storage.
-        with io.open(self.backend.name, "wb") as f:
+        with io.open(self.path, "wb") as f:
             f.truncate(constants.GIB)
 
     def format_index(self):
-        lockspace = os.path.basename(os.path.dirname(self.backend.name))
-        xlease.format_index(lockspace, self.backend)
+        xlease.format_index(
+            self.lockspace,
+            self.backend,
+            alignment=self.alignment,
+            block_size=self.block_size)
 
     def close(self):
         self.backend.close()
 
 
-@pytest.fixture
-def tmp_vol(tmp_storage):
-    tv = TemporaryVolume(tmp_storage)
+@pytest.fixture(params=[
+    pytest.param(
+        (userstorage.PATHS["file-512"], sc.ALIGNMENT_1M),
+        id="file-512-1m"),
+    pytest.param(
+        (userstorage.PATHS["file-4k"], sc.ALIGNMENT_1M),
+        id="file-4k-1m"),
+    pytest.param(
+        (userstorage.PATHS["file-4k"], sc.ALIGNMENT_2M),
+        id="file-4k-2m"),
+    pytest.param(
+        (userstorage.PATHS["file-4k"], sc.ALIGNMENT_4M),
+        id="file-4k-4m"),
+    pytest.param(
+        (userstorage.PATHS["file-4k"], sc.ALIGNMENT_8M),
+        id="file-4k-8m"),
+])
+def tmp_vol(request):
+    storage, alignment = request.param
+    if not os.path.exists(storage.path):
+        pytest.xfail("{} storage not available".format(storage.name))
+
+    tv = TemporaryVolume(storage, alignment)
     yield tv
     tv.close()
 
 
 @pytest.fixture
-def fake_sanlock(monkeypatch):
-    sanlock = FakeSanlock()
+def fake_sanlock(monkeypatch, tmp_vol):
+    sanlock = FakeSanlock(sector_size=tmp_vol.block_size)
     monkeypatch.setattr(xlease, "sanlock", sanlock)
     yield sanlock
 
@@ -128,133 +162,170 @@ class TestIndex:
     def test_metadata(self, tmp_vol, monkeypatch):
         monkeypatch.setattr("time.time", lambda: 123456789)
         tmp_vol.format_index()
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
-            lockspace = os.path.basename(os.path.dirname(vol.path))
             assert vol.version == 1
-            assert vol.lockspace == lockspace
+            assert vol.lockspace == tmp_vol.lockspace
             assert vol.mtime == 123456789
 
     def test_magic_big_endian(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            with io.open(vol.path, "rb") as f:
-                f.seek(xlease.INDEX_BASE)
-                assert f.read(4) == b"\x12\x15\x20\x16"
+        with io.open(tmp_vol.path, "rb") as f:
+            f.seek(tmp_vol.alignment)
+            assert f.read(4) == b"\x12\x15\x20\x16"
 
     def test_bad_magic(self, tmp_vol):
         tmp_vol.zero_storage()
-        self.check_invalid_index(tmp_vol.backend.name)
+        with pytest.raises(xlease.InvalidIndex):
+            xlease.LeasesVolume(
+                tmp_vol.backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size).close()
 
     def test_bad_version(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            with io.open(vol.path, "r+b") as f:
-                f.seek(xlease.INDEX_BASE + 5)
-                f.write(b"blah")
-            self.check_invalid_index(vol.path)
+        with io.open(tmp_vol.path, "r+b") as f:
+            f.seek(tmp_vol.alignment + 5)
+            f.write(b"blah")
+
+        with pytest.raises(xlease.InvalidIndex):
+            xlease.LeasesVolume(
+                tmp_vol.backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size).close()
 
     def test_unsupported_version(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            md = xlease.IndexMetadata(2, "lockspace")
-            with io.open(vol.path, "r+b") as f:
-                f.seek(xlease.INDEX_BASE)
-                f.write(md.bytes())
-            self.check_invalid_index(vol.path)
+        md = xlease.IndexMetadata(2, "lockspace")
+        with io.open(tmp_vol.path, "r+b") as f:
+            f.seek(tmp_vol.alignment)
+            f.write(md.bytes())
+
+        with pytest.raises(xlease.InvalidIndex):
+            xlease.LeasesVolume(
+                tmp_vol.backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size).close()
 
     def test_bad_lockspace(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            with io.open(vol.path, "r+b") as f:
-                f.seek(xlease.INDEX_BASE + 10)
-                f.write(b"\xf0")
-            self.check_invalid_index(vol.path)
+        with io.open(tmp_vol.path, "r+b") as f:
+            f.seek(tmp_vol.alignment + 10)
+            f.write(b"\xf0")
+
+        with pytest.raises(xlease.InvalidIndex):
+            xlease.LeasesVolume(
+                tmp_vol.backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size).close()
 
     def test_bad_mtime(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            with io.open(vol.path, "r+b") as f:
-                f.seek(xlease.INDEX_BASE + 59)
-                f.write(b"not a number")
-            self.check_invalid_index(vol.path)
+        with io.open(tmp_vol.path, "r+b") as f:
+            f.seek(tmp_vol.alignment + 59)
+            f.write(b"not a number")
+
+        with pytest.raises(xlease.InvalidIndex):
+            xlease.LeasesVolume(
+                tmp_vol.backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size).close()
 
     def test_updating(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            md = xlease.IndexMetadata(xlease.INDEX_VERSION, "lockspace",
-                                      updating=True)
-            with io.open(vol.path, "r+b") as f:
-                f.seek(xlease.INDEX_BASE)
-                f.write(md.bytes())
-            self.check_invalid_index(vol.path)
+        md = xlease.IndexMetadata(
+            xlease.INDEX_VERSION, "lockspace", updating=True)
+        with io.open(tmp_vol.path, "r+b") as f:
+            f.seek(tmp_vol.alignment)
+            f.write(md.bytes())
+
+        with pytest.raises(xlease.InvalidIndex):
+            xlease.LeasesVolume(
+                tmp_vol.backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size).close()
 
     def test_truncated_index(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            # Truncate index, reading it should fail.
-            with io.open(vol.path, "r+b") as f:
-                f.truncate(
-                    xlease.INDEX_BASE + xlease.INDEX_SIZE - xlease.BLOCK_SIZE)
-            self.check_invalid_index(vol.path)
+        # Truncate index, reading it should fail.
+        with io.open(tmp_vol.path, "r+b") as f:
+            f.truncate(
+                tmp_vol.alignment + xlease.INDEX_SIZE - tmp_vol.block_size)
 
-    def check_invalid_index(self, path):
-        file = xlease.DirectFile(path)
-        with utils.closing(file):
-            with pytest.raises(xlease.InvalidIndex):
-                vol = xlease.LeasesVolume(file)
-                vol.close()
+        with pytest.raises(xlease.InvalidIndex):
+            xlease.LeasesVolume(
+                tmp_vol.backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size).close()
 
-    def test_format(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+    def test_empty(self, tmp_vol):
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             assert vol.leases() == {}
 
     def test_rebuild_empty(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        # Add underlying sanlock resources.
+        for i in [3, 4, 6]:
+            resource = "%04d" % i
+            offset = xlease.lease_offset(i, tmp_vol.alignment)
+            fake_sanlock.write_resource(
+                tmp_vol.lockspace,
+                resource,
+                [(tmp_vol.path, offset)],
+                align=tmp_vol.alignment,
+                sector=tmp_vol.block_size)
+
+        # Check that the index is empty before rebuilding.
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
-            # Add underlying sanlock resources
-            for i in [3, 4, 6]:
-                resource = "%04d" % i
-                offset = xlease.USER_RESOURCE_BASE + xlease.SLOT_SIZE * i
-                fake_sanlock.write_resource(
-                    vol.lockspace, resource, [(vol.path, offset)])
-            # The index is empty
             assert vol.leases() == {}
 
-            # After rebuilding the index it should contain all the underlying
-            # resources.
-            file = xlease.DirectFile(vol.path)
-            with utils.closing(file):
-                xlease.rebuild_index(vol.lockspace, file)
-            expected = {
-                "0003": {
-                    "offset": xlease.USER_RESOURCE_BASE + xlease.SLOT_SIZE * 3,
-                    "updating": False,
-                },
-                "0004": {
-                    "offset": xlease.USER_RESOURCE_BASE + xlease.SLOT_SIZE * 4,
-                    "updating": False,
-                },
-                "0006": {
-                    "offset": xlease.USER_RESOURCE_BASE + xlease.SLOT_SIZE * 6,
-                    "updating": False,
-                },
-            }
-            file = xlease.DirectFile(vol.path)
-            with utils.closing(file):
-                vol = xlease.LeasesVolume(file)
-                with utils.closing(vol):
-                    assert vol.leases() == expected
+        # Rebuild the index from storage.
+        xlease.rebuild_index(
+            tmp_vol.lockspace,
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
+
+        # After rebuilding the index it should contain all the underlying
+        # resources.
+        expected = {
+            "0003": {
+                "offset": xlease.lease_offset(3, tmp_vol.alignment),
+                "updating": False,
+            },
+            "0004": {
+                "offset": xlease.lease_offset(4, tmp_vol.alignment),
+                "updating": False,
+            },
+            "0006": {
+                "offset": xlease.lease_offset(6, tmp_vol.alignment),
+                "updating": False,
+            },
+        }
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
+        with utils.closing(vol):
+            assert vol.leases() == expected
 
     def test_create_read_failure(self, tmp_vol):
-        file = FailingReader(tmp_vol.backend.name)
+        file = FailingReader(tmp_vol.path)
         with utils.closing(file):
             with pytest.raises(ReadError):
-                xlease.LeasesVolume(file)
+                xlease.LeasesVolume(
+                    file,
+                    alignment=tmp_vol.alignment,
+                    block_size=tmp_vol.block_size)
 
     def test_lookup_missing(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             with pytest.raises(se.NoSuchLease):
                 vol.lookup(make_uuid())
@@ -262,7 +333,10 @@ class TestIndex:
     def test_lookup_updating(self, tmp_vol):
         record = xlease.Record(make_uuid(), 0, updating=True)
         tmp_vol.write_records((42, record))
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             leases = vol.leases()
             assert leases[record.resource]["updating"]
@@ -270,32 +344,43 @@ class TestIndex:
                 vol.lookup(record.resource)
 
     def test_add(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             lease_id = make_uuid()
             lease = vol.add(lease_id)
             assert lease.lockspace == vol.lockspace
             assert lease.resource == lease_id
             assert lease.path == vol.path
-            res = fake_sanlock.read_resource(lease.path, lease.offset)
+            res = fake_sanlock.read_resource(
+                lease.path,
+                lease.offset,
+                align=tmp_vol.alignment,
+                sector=tmp_vol.block_size)
             assert res["lockspace"] == lease.lockspace
             assert res["resource"] == lease.resource
 
     def test_add_write_failure(self, tmp_vol):
-        base = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(base):
-            file = FailingWriter(base.path)
-            with utils.closing(file):
-                vol = xlease.LeasesVolume(file)
-                with utils.closing(vol):
-                    lease_id = make_uuid()
-                    with pytest.raises(WriteError):
-                        vol.add(lease_id)
-                    # Must succeed becuase writng to storage failed
-                    assert lease_id not in vol.leases()
+        backend = FailingWriter(tmp_vol.path)
+        with utils.closing(backend):
+            vol = xlease.LeasesVolume(
+                backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size)
+            with utils.closing(vol):
+                lease_id = make_uuid()
+                with pytest.raises(WriteError):
+                    vol.add(lease_id)
+                # Must succeed becuase writng to storage failed
+                assert lease_id not in vol.leases()
 
     def test_add_sanlock_failure(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             lease_id = make_uuid()
             # Make sanlock fail to write a resource
@@ -308,11 +393,18 @@ class TestIndex:
             assert lease["updating"]
             # There should be no lease on storage
             with pytest.raises(fake_sanlock.SanlockException) as e:
-                fake_sanlock.read_resource(vol.path, lease["offset"])
+                fake_sanlock.read_resource(
+                    vol.path,
+                    lease["offset"],
+                    align=tmp_vol.alignment,
+                    sector=tmp_vol.block_size)
                 assert e.exception.errno == fake_sanlock.SANLK_LEADER_MAGIC
 
     def test_leases(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             uuid = make_uuid()
             lease_info = vol.add(uuid)
@@ -326,18 +418,28 @@ class TestIndex:
             assert leases == expected
 
     def test_add_exists(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             lease_id = make_uuid()
             lease = vol.add(lease_id)
             with pytest.raises(xlease.LeaseExists):
                 vol.add(lease_id)
-            res = fake_sanlock.read_resource(lease.path, lease.offset)
+            res = fake_sanlock.read_resource(
+                lease.path,
+                lease.offset,
+                align=tmp_vol.alignment,
+                sector=tmp_vol.block_size)
             assert res["lockspace"] == lease.lockspace
             assert res["resource"] == lease.resource
 
     def test_lookup_exists(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             lease_id = make_uuid()
             add_info = vol.add(lease_id)
@@ -345,7 +447,10 @@ class TestIndex:
             assert add_info == lookup_info
 
     def test_remove_exists(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             leases = [make_uuid() for i in range(3)]
             for lease in leases:
@@ -353,14 +458,21 @@ class TestIndex:
             lease = vol.lookup(leases[1])
             vol.remove(lease.resource)
             assert lease.resource not in vol.leases()
-            res = fake_sanlock.read_resource(lease.path, lease.offset)
+            res = fake_sanlock.read_resource(
+                lease.path,
+                lease.offset,
+                align=tmp_vol.alignment,
+                sector=tmp_vol.block_size)
             # There is no sanlock api for removing a resource, so we mark a
             # removed resource with empty (invalid) lockspace and lease id.
             assert res["lockspace"] == ""
             assert res["resource"] == ""
 
     def test_remove_missing(self, tmp_vol):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             lease_id = make_uuid()
             with pytest.raises(se.NoSuchLease):
@@ -369,19 +481,23 @@ class TestIndex:
     def test_remove_write_failure(self, tmp_vol):
         record = xlease.Record(make_uuid(), 0, updating=True)
         tmp_vol.write_records((42, record))
-        base = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(base):
-            file = FailingWriter(base.path)
-            with utils.closing(file):
-                vol = xlease.LeasesVolume(file)
-                with utils.closing(vol):
-                    with pytest.raises(WriteError):
-                        vol.remove(record.resource)
-                    # Must succeed becuase writng to storage failed
-                    assert record.resource in vol.leases()
+        backend = FailingWriter(tmp_vol.path)
+        with utils.closing(backend):
+            vol = xlease.LeasesVolume(
+                backend,
+                alignment=tmp_vol.alignment,
+                block_size=tmp_vol.block_size)
+            with utils.closing(vol):
+                with pytest.raises(WriteError):
+                    vol.remove(record.resource)
+                # Must succeed becuase writng to storage failed
+                assert record.resource in vol.leases()
 
     def test_remove_sanlock_failure(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             lease_id = make_uuid()
             vol.add(lease_id)
@@ -395,12 +511,19 @@ class TestIndex:
             lease = vol.leases()[lease_id]
             assert lease["updating"]
             # There lease should still be on storage
-            res = fake_sanlock.read_resource(vol.path, lease["offset"])
+            res = fake_sanlock.read_resource(
+                vol.path,
+                lease["offset"],
+                align=tmp_vol.alignment,
+                sector=tmp_vol.block_size)
             assert res["lockspace"] == vol.lockspace
             assert res["resource"] == lease_id
 
     def test_add_first_free_slot(self, tmp_vol, fake_sanlock):
-        vol = xlease.LeasesVolume(tmp_vol.backend)
+        vol = xlease.LeasesVolume(
+            tmp_vol.backend,
+            alignment=tmp_vol.alignment,
+            block_size=tmp_vol.block_size)
         with utils.closing(vol):
             uuids = [make_uuid() for i in range(4)]
             for uuid in uuids[:3]:
@@ -408,15 +531,19 @@ class TestIndex:
             vol.remove(uuids[1])
             vol.add(uuids[3])
             leases = vol.leases()
+
             # The first lease in the first slot
-            assert leases[uuids[0]]["offset"] == xlease.USER_RESOURCE_BASE
+            offset = xlease.lease_offset(0, tmp_vol.alignment)
+            assert leases[uuids[0]]["offset"] == offset
+
             # The forth lease was added in the second slot after the second
             # lease was removed.
-            assert (leases[uuids[3]]["offset"] ==
-                    xlease.USER_RESOURCE_BASE + xlease.SLOT_SIZE)
+            offset = xlease.lease_offset(1, tmp_vol.alignment)
+            assert leases[uuids[3]]["offset"] == offset
+
             # The third lease in the third slot
-            assert (leases[uuids[2]]["offset"] ==
-                    xlease.USER_RESOURCE_BASE + xlease.SLOT_SIZE * 2)
+            offset = xlease.lease_offset(2, tmp_vol.alignment)
+            assert leases[uuids[2]]["offset"] == offset
 
     @pytest.mark.slow
     def test_time_lookup(self, tmp_vol):
@@ -427,27 +554,34 @@ from vdsm import utils
 from vdsm.storage import exception as se
 from vdsm.storage import xlease
 
-path = "%s"
+path = "%(path)s"
+alignment = %(alignment)d
+block_size = %(block_size)d
 lockspace = os.path.basename(os.path.dirname(path))
 lease_id = make_uuid()
 
 def bench():
     file = xlease.DirectFile(path)
     with utils.closing(file):
-        vol = xlease.LeasesVolume(file)
+        vol = xlease.LeasesVolume(
+            file,
+            alignment=alignment,
+            block_size=block_size)
         with utils.closing(vol, log="test"):
             try:
                 vol.lookup(lease_id)
             except se.NoSuchLease:
                 pass
 """
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            count = 100
-            elapsed = timeit.timeit("bench()", setup=setup % vol.path,
-                                    number=count)
-            print("%d lookups in %.6f seconds (%.6f seconds per lookup)"
-                  % (count, elapsed, elapsed / count))
+        setup = setup % {
+            "path": tmp_vol.path,
+            "alignment": tmp_vol.alignment,
+            "block_size": tmp_vol.block_size,
+        }
+        count = 100
+        elapsed = timeit.timeit("bench()", setup=setup, number=count)
+        print("%d lookups in %.6f seconds (%.6f seconds per lookup)"
+              % (count, elapsed, elapsed / count))
 
     @pytest.mark.slow
     def test_time_add(self, tmp_vol, fake_sanlock):
@@ -457,26 +591,33 @@ from testlib import make_uuid
 from vdsm import utils
 from vdsm.storage import xlease
 
-path = "%s"
+path = "%(path)s"
+alignment = %(alignment)d
+block_size = %(block_size)d
 lockspace = os.path.basename(os.path.dirname(path))
 
 def bench():
     lease_id = make_uuid()
     file = xlease.DirectFile(path)
     with utils.closing(file):
-        vol = xlease.LeasesVolume(file)
+        vol = xlease.LeasesVolume(
+            file,
+            alignment=alignment,
+            block_size=block_size)
         with utils.closing(vol, log="test"):
             vol.add(lease_id)
 """
-        vol = xlease.LeasesVolume(tmp_vol.backend)
-        with utils.closing(vol):
-            count = 100
-            elapsed = timeit.timeit("bench()", setup=setup % vol.path,
-                                    number=count)
-            # Note: this does not include the time to create the real sanlock
-            # resource.
-            print("%d adds in %.6f seconds (%.6f seconds per add)"
-                  % (count, elapsed, elapsed / count))
+        setup = setup % {
+            "path": tmp_vol.path,
+            "alignment": tmp_vol.alignment,
+            "block_size": tmp_vol.block_size,
+        }
+        count = 100
+        elapsed = timeit.timeit("bench()", setup=setup, number=count)
+        # Note: this does not include the time to create the real sanlock
+        # resource.
+        print("%d adds in %.6f seconds (%.6f seconds per add)"
+              % (count, elapsed, elapsed / count))
 
 
 @pytest.fixture(params=[
@@ -504,15 +645,15 @@ def direct_file(request):
 
 class TestDirectFile:
 
-    def test_name(self, tmp_storage, direct_file):
-        file = direct_file(tmp_storage)
+    def test_name(self, user_storage, direct_file):
+        file = direct_file(user_storage.path)
         with utils.closing(file):
-            assert file.name == tmp_storage
+            assert file.name == user_storage.path
 
-    def test_size(self, tmp_storage, direct_file):
-        with io.open(tmp_storage, "wb") as f:
+    def test_size(self, user_storage, direct_file):
+        with io.open(user_storage.path, "wb") as f:
             f.truncate(constants.GIB)
-        file = direct_file(tmp_storage)
+        file = direct_file(user_storage.path)
         with utils.closing(file):
             assert file.size() == constants.GIB
 
